(svn r1297) Language fixes in the source.. (ln-)
authormiham
Wed, 29 Dec 2004 13:13:29 +0000
changeset 826 0e2b569b737b
parent 825 a830d6e67739
child 827 2026d158133d
(svn r1297) Language fixes in the source.. (ln-)
ai.h
ai_new.c
ai_pathfinder.c
aystar.c
command.c
misc.c
network.c
network_data.c
network_server.c
order_cmd.c
player.h
queue.c
rail_cmd.c
roadveh_cmd.c
unix.c
vehicle.c
win32.c
window.h
--- a/ai.h	Wed Dec 29 11:00:34 2004 +0000
+++ b/ai.h	Wed Dec 29 13:13:29 2004 +0000
@@ -71,7 +71,7 @@
 #define AI_LOCATE_ROUTE_MAX_COUNTER 200
 
 // How many days must there be between building the first station and the second station
-//  within one city. This number is in days and should be more then 4 months.
+//  within one city. This number is in days and should be more than 4 months.
 #define AI_CHECKCITY_DATE_BETWEEN 180
 
 // How many cargo is needed for one station in a city?
@@ -130,7 +130,7 @@
 //  reuse the station instead of building a new one!
 #define AI_STATION_REUSE_MULTIPLER 2
 
-// No more then this amount of vehicles per station..
+// No more than this amount of vehicles per station..
 #define AI_CHECK_MAX_VEHICLE_PER_STATION 10
 
 // How many thick between building 2 vehicles
@@ -149,7 +149,7 @@
 //   while old vehicles stay longer, because we do get less in return.
 #define AI_MINIMUM_ROUTE_PROFIT 1000
 
-// A vehicle is considered lost when he his cargo is more then 180 days old
+// A vehicle is considered lost when he his cargo is more than 180 days old
 #define AI_VEHICLE_LOST_DAYS 180
 
 // How many times may the AI try to find a route before it gives up
--- a/ai_new.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/ai_new.c	Wed Dec 29 13:13:29 2004 +0000
@@ -408,7 +408,7 @@
    			int max_cargo = DEREF_TOWN(p->ainew.from_ic)->max_pass + DEREF_TOWN(p->ainew.temp)->max_pass;
    			max_cargo -= DEREF_TOWN(p->ainew.from_ic)->act_pass + DEREF_TOWN(p->ainew.temp)->act_pass;
    			// max_cargo is now the amount of cargo we can move between the two cities
-   			// If it is more then the distance, we allow it
+   			// If it is more than the distance, we allow it
    			if (GetTileDist(DEREF_TOWN(p->ainew.from_ic)->xy, DEREF_TOWN(p->ainew.temp)->xy) <= max_cargo * AI_LOCATEROUTE_BUS_CARGO_DISTANCE) {
    				// We found a good city/industry, save the data of it
    				p->ainew.to_ic = p->ainew.temp;
@@ -493,7 +493,7 @@
    	p->ainew.last_id = p->ainew.temp;
 }
 
-// Check if there are not more then a certain amount of vehicles pointed to a certain
+// Check if there are not more than a certain amount of vehicles pointed to a certain
 //  station. This to prevent 10 busses going to one station, which gives... problems ;)
 static bool AiNew_CheckVehicleStation(Player *p, Station *st) {
 	int count = 0;
@@ -558,7 +558,7 @@
 
     // First, we are going to look at the stations that already exist inside the city
     //  If there is enough cargo left in the station, we take that station
-    //  If that is not possible, and there are more then 2 stations in the city, abort
+    //  If that is not possible, and there are more than 2 stations in the city, abort
 	i = AiNew_PickVehicle(p);
 	// Euhmz, this should not happen _EVER_
 	// Quit finding a route...
@@ -588,7 +588,7 @@
 	}
 	// We are going to add a new station...
 	if (new_tile == 0) count++;
-	// No more then 2 stations allowed in a city
+	// No more than 2 stations allowed in a city
 	//  This is because only the best 2 stations of one cargo do get any cargo
 	if (count > 2) {
 		p->ainew.state = AI_STATE_NOTHING;
@@ -851,7 +851,7 @@
     	else
     		max_cargo = DEREF_INDUSTRY(p->ainew.to_ic)->total_production[0];
 
-    	// This is because moving 60% is more then we can dream of!
+    	// This is because moving 60% is more than we can dream of!
     	max_cargo *= 0.6;
     	// We want all the cargo to be gone in a month.. so, we know the cargo it delivers
     	//  we know what the vehicle takes with him, and we know the time it takes him
@@ -1134,7 +1134,7 @@
         p->ainew.veh_main_id = p->ainew.veh_id;
     }
 
-    // When more then 1 vehicle, we send them to different directions
+    // When more than 1 vehicle, we send them to different directions
 		idx = 0;
 		order.type = OT_GOTO_STATION;
 		order.flags = 0;
@@ -1188,7 +1188,7 @@
 
 	// When a vehicle is older then 1 year, it should make money...
 	if (v->age > 360) {
-		// If both years together are not more then AI_MINIMUM_ROUTE_PROFIT,
+		// If both years together are not more than AI_MINIMUM_ROUTE_PROFIT,
 		//  it is not worth the line I guess...
 		if (v->profit_last_year + v->profit_this_year < AI_MINIMUM_ROUTE_PROFIT ||
 			(v->reliability * 100 >> 16) < 40) {
--- a/ai_pathfinder.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/ai_pathfinder.c	Wed Dec 29 13:13:29 2004 +0000
@@ -140,7 +140,7 @@
 		r = GetTileDist(current->tile, PathFinderInfo->end_tile_tl);
 		r2 = GetTileDist(current->tile, PathFinderInfo->end_tile_br);
 	}
-	// See if the bottomright is faster then the topleft..
+	// See if the bottomright is faster than the topleft..
 	if (r2 < r) r = r2;
 	return r * AI_PATHFINDER_H_MULTIPLER;
 }
@@ -429,7 +429,7 @@
 		if (parent->path.parent != NULL && parent->path.parent->parent != NULL) {
 			int dir1 = AiNew_GetRailDirection(parent->path.parent->node.tile, parent->path.node.tile, current->tile);
 			int dir2 = AiNew_GetRailDirection(parent->path.parent->parent->node.tile, parent->path.parent->node.tile, parent->path.node.tile);
-			// First, see if we are on diagonal path, that is better then straight path
+			// First, see if we are on diagonal path, that is better than straight path
 			if (dir1 > 1) { res -= AI_PATHFINDER_DIAGONAL_BONUS; }
 
 			// First see if they are different
--- a/aystar.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/aystar.c	Wed Dec 29 13:13:29 2004 +0000
@@ -215,7 +215,7 @@
 int AyStarMain_Main(AyStar *aystar) {
 	int r, i = 0;
 	// Loop through the OpenList
-	//  Quit if result is no AYSTAR_STILL_BUSY or is more then loops_per_tick
+	//  Quit if result is no AYSTAR_STILL_BUSY or is more than loops_per_tick
 	while ((r = aystar->loop(aystar)) == AYSTAR_STILL_BUSY && (aystar->loops_per_tick == 0 || ++i < aystar->loops_per_tick)) { }
 #ifdef AYSTAR_DEBUG
 	if (r == AYSTAR_FOUND_END_NODE)
--- a/command.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/command.c	Wed Dec 29 13:13:29 2004 +0000
@@ -413,7 +413,7 @@
 	assert((cmd & 0xFF) < lengthof(_command_proc_table));
 	proc = _command_proc_table[cmd & 0xFF];
 
-	// Some commands have a different output in dryrun then the realrun
+	// Some commands have a different output in dryrun than the realrun
 	//  e.g.: if you demolish a whole town, the dryrun would say okay.
 	//  but by really destroying, your rating drops and at a certain point
 	//  it will fail. so res and res2 are different
@@ -474,7 +474,7 @@
 	_yearly_expenses_type = 0;
 	res2 = proc(x,y, flags|DC_EXEC, p1, p2);
 
-	// If notest is on, it means the result of the test can be different then
+	// If notest is on, it means the result of the test can be different than
 	//   the real command.. so ignore the test
 	if (!notest && !((cmd & CMD_NO_TEST_IF_IN_NETWORK) && _networking)) {
 		assert(res == res2); // sanity check
--- a/misc.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/misc.c	Wed Dec 29 13:13:29 2004 +0000
@@ -713,10 +713,10 @@
 
 int FindFirstBit(uint32 value)
 {
-	// This is much faster then the one that was before here.
+	// This is much faster than the one that was before here.
 	//  Created by Darkvater.. blame him if it is wrong ;)
 	// Btw, the macro FINDFIRSTBIT is better to use when your value is
-	//  not more then 128.
+	//  not more than 128.
 	byte i = 0;
 	if (value & 0xffff0000) { value >>= 16; i += 16; }
 	if (value & 0x0000ff00) { value >>= 8;  i += 8; }
--- a/network.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/network.c	Wed Dec 29 13:13:29 2004 +0000
@@ -1310,7 +1310,7 @@
 	memset(&_network_game_info, 0, sizeof(_network_game_info));
 
 	/* XXX - Hard number here, because the strings can currently handle no more
-	    then 10 clients -- TrueLight */
+	    than 10 clients -- TrueLight */
 	_network_game_info.clients_max = 10;
 
 	// Let's load the network in windows
--- a/network_data.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/network_data.c	Wed Dec 29 13:13:29 2004 +0000
@@ -387,7 +387,7 @@
 	if (_network_server) {
 		// If we are the server, we queue the command in our 'special' queue.
 		//   In theory, we could execute the command right away, but then the
-		//   client on the server can do everything 1 tick faster then others.
+		//   client on the server can do everything 1 tick faster than others.
 		//   So to keep the game fair, we delay the command with 1 tick
 		//   which gives about the same speed as most clients.
 		NetworkClientState *cs;
--- a/order_cmd.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/order_cmd.c	Wed Dec 29 13:13:29 2004 +0000
@@ -350,7 +350,7 @@
 	}
 
 	// CMD_NO_TEST_IF_IN_NETWORK is used here, because CMD_INSERT_ORDER checks if the
-	//  order number is one more then the current amount of orders, and because
+	//  order number is one more than the current amount of orders, and because
 	//  in network the commands are queued before send, the second insert always
 	//  fails in test mode. By bypassing the test-mode, that no longer is a problem.
 	for (i = 0; bak->order[i].type != OT_NOTHING; ++i)
--- a/player.h	Wed Dec 29 11:00:34 2004 +0000
+++ b/player.h	Wed Dec 29 13:13:29 2004 +0000
@@ -93,9 +93,9 @@
 	uint tick;
 	uint idle;
 
-	int temp; 	// A value used in more then one function, but it just temporary
+	int temp; 	// A value used in more than one function, but it just temporary
 				// The use is pretty simple: with this we can 'think' about stuff
-				//   in more then one tick, and more then one AI. A static will not
+				//   in more than one tick, and more than one AI. A static will not
 				//   do, because they are not saved. This way, the AI is almost human ;)
 	int counter; 	// For the same reason as temp, we have counter. It can count how
 					//  long we are trying something, and just abort if it takes too long
--- a/queue.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/queue.c	Wed Dec 29 13:13:29 2004 +0000
@@ -355,7 +355,7 @@
 			j = i;
 			// Check if we have 2 childs
 			if (2*j+1 <= q->data.binaryheap.size) {
-				// Is this child smaller then the parent?
+				// Is this child smaller than the parent?
 				if (BIN_HEAP_ARR(j).priority >= BIN_HEAP_ARR(2*j).priority) {i = 2*j; }
 				// Yes, we _need_ to use i here, not j, because we want to have the smallest child
 				//  This way we get that straight away!
@@ -365,7 +365,7 @@
 				if (BIN_HEAP_ARR(j).priority >= BIN_HEAP_ARR(2*j).priority) { i = 2*j; }
 			}
 
-			// One of our childs is smaller then we are, switch
+			// One of our childs is smaller than we are, switch
 			if (i != j) {
 				temp = BIN_HEAP_ARR(j);
 				BIN_HEAP_ARR(j) = BIN_HEAP_ARR(i);
--- a/rail_cmd.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/rail_cmd.c	Wed Dec 29 13:13:29 2004 +0000
@@ -1029,7 +1029,7 @@
 		if ((signal_ctr %	signal_density) == 0 ) {
 			ret = DoCommand(x, y, (railbit & 7) | semaphores, signals, flags, (mode == 1) ? CMD_REMOVE_SIGNALS : CMD_BUILD_SIGNALS);
 
-			/* Abort placement for any other error then NOT_SUITEABLE_TRACK
+			/* Abort placement for any other error than NOT_SUITABLE_TRACK
 			 * This includes vehicles on track, competitor's tracks, etc. */
 			if (ret == CMD_ERROR) {
 				if (_error_message != STR_1005_NO_SUITABLE_RAILROAD_TRACK && mode != 1) {
--- a/roadveh_cmd.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/roadveh_cmd.c	Wed Dec 29 13:13:29 2004 +0000
@@ -694,7 +694,7 @@
 	u = VehicleFromPos(TILE_FROM_XY(x,y), &rvf, (VehicleFromPosProc*)EnumCheckRoadVehClose);
 
 	// This code protects a roadvehicle from being blocked for ever
-	//  If more then 1480 / 74 days a road vehicle is blocked, it will
+	//  If more than 1480 / 74 days a road vehicle is blocked, it will
 	//  drive just through it. The ultimate backup-code of TTD.
 	// It can be disabled.
 	if (u == NULL) {
--- a/unix.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/unix.c	Wed Dec 29 13:13:29 2004 +0000
@@ -372,7 +372,7 @@
 	 Not needed for *nix. */
 byte GetOSVersion()
 {
-	return 2;  // any arbitrary number bigger then 0
+	return 2;  // any arbitrary number bigger than 0
 				// numbers lower than 2 breaks default music selection on mac
 }
 
--- a/vehicle.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/vehicle.c	Wed Dec 29 13:13:29 2004 +0000
@@ -203,7 +203,7 @@
 	/* random_bits is used to pick out a random sprite for vehicles
 	    which are technical the same (newgrf stuff).
 	   Because RandomRange() results in desyncs, and because it does
-	    not really matter that one client has other visual vehicles then
+	    not really matter that one client has other visual vehicles than
 	    the other, it can be InteractiveRandomRange() without any problem
 	*/
 	v->random_bits = InteractiveRandomRange(256);
--- a/win32.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/win32.c	Wed Dec 29 13:13:29 2004 +0000
@@ -1842,7 +1842,7 @@
 #ifdef WIN32_ENABLE_DIRECTMUSIC_SUPPORT
 	{"dmusic", "DirectMusic MIDI Driver",	&_dmusic_midi_driver,	Windows_2000},
 #endif
-	// Win32 MIDI driver has higher priority then DMusic, so this one is chosen
+	// Win32 MIDI driver has higher priority than DMusic, so this one is chosen
 	{"win32", "Win32 MIDI Driver",	&_win32_music_driver,				Windows_NT3_51},
 	{NULL}
 };
--- a/window.h	Wed Dec 29 11:00:34 2004 +0000
+++ b/window.h	Wed Dec 29 13:13:29 2004 +0000
@@ -183,7 +183,7 @@
 #define WP(ptr,str) (*(str*)(ptr)->custom)
 // querystr_d is the bigest struct that comes in w->custom
 //  because 64-bit systems use 64-bit pointers, it is bigger on a 64-bit system
-//  then on a 32-bit system. Therefor the size is calculated from querystr_d
+//  than on a 32-bit system. Therefore, the size is calculated from querystr_d
 //  instead of a hardcoded number.
 // if any struct becomes bigger the querystr_d, it should be replaced.
 #define WINDOW_CUSTOM_SIZE sizeof(querystr_d)
--- a/network_server.c	Wed Dec 29 11:00:34 2004 +0000
+++ b/network_server.c	Wed Dec 29 13:13:29 2004 +0000
@@ -1372,7 +1372,7 @@
 		if (!found_name) {
 			// Try a new name (<name> #1, <name> #2, and so on)
 
 			// Stop if we tried for more then 50 times..
 			if (number++ > 50) break;
 			snprintf(new_name, NETWORK_CLIENT_NAME_LENGTH, "%s #%d", original_name, number);
 		}
@@ -1450,7 +1450,7 @@
 				if (lag > 3) {
 					// Client did still not report in after 4 game-day, drop him
 					//  (that is, the 3 of above, + 1 before any lag is counted)
-					IConsolePrintF(_iconsole_color_error,"Client #%d is dropped because the client did not respond for more then 4 game-days", cs->index);
+					IConsolePrintF(_iconsole_color_error,"Client #%d is dropped because the client did not respond for more than 4 game-days", cs->index);
 					NetworkCloseClient(cs);
 					continue;
 				}
@@ -1372,7 +1372,7 @@
 			// Try a new name (<name> #1, <name> #2, and so on)
 
-			// Stop if we tried for more then 50 times..
+			// Stop if we tried for more than 50 times..
 			if (number++ > 50) break;
 			snprintf(new_name, NETWORK_CLIENT_NAME_LENGTH, "%s #%d", original_name, number);